@@ -145,7 +145,7 @@ init_slang_keys (void)
     }
     else if (!strcmp (term, "mach") || !strcmp (term, "mach-color"))
     {
-        fprintf(stderr, "Tell me if you see this! <adamm@galacticasoftware.com>\n");
+        fprintf(stderr, "Tell me if you see this! <adamm@zombino.com>\n");
     	SLkp_define_keysym ("\177", LPE_BACKSPACE_KEY);
     }
     else {
